==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1SubjectRulesReviewStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1SubjectRulesReviewStatusFluent<A extends V1beta1SubjectRulesReviewStatusFluent<A>> extends Fluent<A>{


    public String getEvaluationError();
    public A withEvaluationError(String evaluationError);
    public Boolean hasEvaluationError();
    public Boolean isIncomplete();
    public A withIncomplete(Boolean incomplete);
    public Boolean hasIncomplete();
    public A withNewIncomplete(boolean arg1);
    public A withNewIncomplete(String arg1);
    public A addToNonResourceRules(int index,V1beta1NonResourceRule item);
    public A setToNonResourceRules(int index,V1beta1NonResourceRule item);
    public A addToNonResourceRules(V1beta1NonResourceRule... items);
    public A addAllToNonResourceRules(Collection<V1beta1NonResourceRule> items);
    public A removeFromNonResourceRules(V1beta1NonResourceRule... items);
    public A removeAllFromNonResourceRules(Collection<V1beta1NonResourceRule> items);
    
/**
 * This method has been deprecated, please use method buildNonResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1NonResourceRule> getNonResourceRules();
    public List<V1beta1NonResourceRule> buildNonResourceRules();
    public V1beta1NonResourceRule buildNonResourceRule(int index);
    public V1beta1NonResourceRule buildFirstNonResourceRule();
    public V1beta1NonResourceRule buildLastNonResourceRule();
    public V1beta1NonResourceRule buildMatchingNonResourceRule(io.kubernetes.client.fluent.Predicate<V1beta1NonResourceRuleBuilder> predicate);
    public A withNonResourceRules(List<V1beta1NonResourceRule> nonResourceRules);
    public A withNonResourceRules(V1beta1NonResourceRule... nonResourceRules);
    public Boolean hasNonResourceRules();
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRuleLike(V1beta1NonResourceRule item);
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> setNewNonResourceRuleLike(int index,V1beta1NonResourceRule item);
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editNonResourceRule(int index);
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editFirstNonResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editLastNonResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editMatchingNonResourceRule(io.kubernetes.client.fluent.Predicate<V1beta1NonResourceRuleBuilder> predicate);
    public A addToResourceRules(int index,V1beta1ResourceRule item);
    public A setToResourceRules(int index,V1beta1ResourceRule item);
    public A addToResourceRules(V1beta1ResourceRule... items);
    public A addAllToResourceRules(Collection<V1beta1ResourceRule> items);
    public A removeFromResourceRules(V1beta1ResourceRule... items);
    public A removeAllFromResourceRules(Collection<V1beta1ResourceRule> items);
    
/**
 * This method has been deprecated, please use method buildResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1ResourceRule> getResourceRules();
    public List<V1beta1ResourceRule> buildResourceRules();
    public V1beta1ResourceRule buildResourceRule(int index);
    public V1beta1ResourceRule buildFirstResourceRule();
    public V1beta1ResourceRule buildLastResourceRule();
    public V1beta1ResourceRule buildMatchingResourceRule(io.kubernetes.client.fluent.Predicate<V1beta1ResourceRuleBuilder> predicate);
    public A withResourceRules(List<V1beta1ResourceRule> resourceRules);
    public A withResourceRules(V1beta1ResourceRule... resourceRules);
    public Boolean hasResourceRules();
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRuleLike(V1beta1ResourceRule item);
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> setNewResourceRuleLike(int index,V1beta1ResourceRule item);
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editResourceRule(int index);
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editFirstResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editLastResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editMatchingResourceRule(io.kubernetes.client.fluent.Predicate<V1beta1ResourceRuleBuilder> predicate);

    public interface NonResourceRulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1NonResourceRuleFluent<V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<N>>{

        
    public N and();    public N endNonResourceRule();
}
    public interface ResourceRulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1ResourceRuleFluent<V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<N>>{

        
    public N and();    public N endResourceRule();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1SubjectRulesReviewStatusFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1SubjectRulesReviewStatusFluent<A extends V1beta1SubjectRulesReviewStatusFluent<A>> extends Fluent<A>{


    public String getEvaluationError();
    public A withEvaluationError(String evaluationError);
    public Boolean hasEvaluationError();
    public A withNewEvaluationError(String arg1);
    public A withNewEvaluationError(StringBuilder arg1);
    public A withNewEvaluationError(StringBuffer arg1);
    public Boolean isIncomplete();
    public A withIncomplete(Boolean incomplete);
    public Boolean hasIncomplete();
    public A withNewIncomplete(String arg1);
    public A withNewIncomplete(boolean arg1);
    public A addToNonResourceRules(int index,V1beta1NonResourceRule item);
    public A setToNonResourceRules(int index,V1beta1NonResourceRule item);
    public A addToNonResourceRules(V1beta1NonResourceRule... items);
    public A addAllToNonResourceRules(Collection<V1beta1NonResourceRule> items);
    public A removeFromNonResourceRules(V1beta1NonResourceRule... items);
    public A removeAllFromNonResourceRules(Collection<V1beta1NonResourceRule> items);
    
/**
 * This method has been deprecated, please use method buildNonResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1NonResourceRule> getNonResourceRules();
    public List<V1beta1NonResourceRule> buildNonResourceRules();
    public V1beta1NonResourceRule buildNonResourceRule(int index);
    public V1beta1NonResourceRule buildFirstNonResourceRule();
    public V1beta1NonResourceRule buildLastNonResourceRule();
    public V1beta1NonResourceRule buildMatchingNonResourceRule(io.kubernetes.client.fluent.Predicate<V1beta1NonResourceRuleBuilder> predicate);
    public Boolean hasMatchingNonResourceRule(io.kubernetes.client.fluent.Predicate<V1beta1NonResourceRuleBuilder> predicate);
    public A withNonResourceRules(List<V1beta1NonResourceRule> nonResourceRules);
    public A withNonResourceRules(V1beta1NonResourceRule... nonResourceRules);
    public Boolean hasNonResourceRules();
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRuleLike(V1beta1NonResourceRule item);
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> setNewNonResourceRuleLike(int index,V1beta1NonResourceRule item);
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editNonResourceRule(int index);
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editFirstNonResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editLastNonResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editMatchingNonResourceRule(io.kubernetes.client.fluent.Predicate<V1beta1NonResourceRuleBuilder> predicate);
    public A addToResourceRules(int index,V1beta1ResourceRule item);
    public A setToResourceRules(int index,V1beta1ResourceRule item);
    public A addToResourceRules(V1beta1ResourceRule... items);
    public A addAllToResourceRules(Collection<V1beta1ResourceRule> items);
    public A removeFromResourceRules(V1beta1ResourceRule... items);
    public A removeAllFromResourceRules(Collection<V1beta1ResourceRule> items);
    
/**
 * This method has been deprecated, please use method buildResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1ResourceRule> getResourceRules();
    public List<V1beta1ResourceRule> buildResourceRules();
    public V1beta1ResourceRule buildResourceRule(int index);
    public V1beta1ResourceRule buildFirstResourceRule();
    public V1beta1ResourceRule buildLastResourceRule();
    public V1beta1ResourceRule buildMatchingResourceRule(io.kubernetes.client.fluent.Predicate<V1beta1ResourceRuleBuilder> predicate);
    public Boolean hasMatchingResourceRule(io.kubernetes.client.fluent.Predicate<V1beta1ResourceRuleBuilder> predicate);
    public A withResourceRules(List<V1beta1ResourceRule> resourceRules);
    public A withResourceRules(V1beta1ResourceRule... resourceRules);
    public Boolean hasResourceRules();
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRuleLike(V1beta1ResourceRule item);
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> setNewResourceRuleLike(int index,V1beta1ResourceRule item);
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editResourceRule(int index);
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editFirstResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editLastResourceRule();
    public V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editMatchingResourceRule(io.kubernetes.client.fluent.Predicate<V1beta1ResourceRuleBuilder> predicate);

    public interface NonResourceRulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1NonResourceRuleFluent<V1beta1SubjectRulesReviewStatusFluent.NonResourceRulesNested<N>>{

        
    public N and();    public N endNonResourceRule();
}
    public interface ResourceRulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1ResourceRuleFluent<V1beta1SubjectRulesReviewStatusFluent.ResourceRulesNested<N>>{

        
    public N and();    public N endResourceRule();
}


}
